From 1aaadd3b2d45d7cb243264d25dd534ccdcd83159 Mon Sep 17 00:00:00 2001
From: =?UTF-8?q?Rodrigo=20Ram=C3=ADrez=20Norambuena?= <a@rodrigoramirez.com>
Date: Sat, 7 Sep 2019 23:30:22 -0300
Subject: [PATCH 4/5] Refactor: Move the view for Robots inside a text file and
 include tests


diff --git a/pgweb/core/tests/__init__.py b/pgweb/core/tests/__init__.py
new file mode 100644
index 0000000..e69de29
diff --git a/pgweb/core/tests/test_robots.py b/pgweb/core/tests/test_robots.py
new file mode 100644
index 0000000..78297a7
--- /dev/null
+++ b/pgweb/core/tests/test_robots.py
@@ -0,0 +1,24 @@
+from django.test import Client
+from django.test import TestCase
+
+
+class RobotsTest(TestCase):
+
+    def setUp(self):
+        self.client = Client()
+        self.url = '/robots.txt'
+
+    def test_content_type(self):
+        """Expect get content_type text/plain"""
+        response = self.client.get(self.url)
+        self.assertEqual(response.__getitem__('content-type'), 'text/plain')
+
+    def test_http_code(self):
+        """Expect get 200 http code"""
+        response = self.client.get(self.url)
+        self.assertEqual(response.status_code, 200)
+
+    def test_content(self):
+        """Expect get content"""
+        response = self.client.get(self.url)
+        assert 'User-agent' in str(response.content)
diff --git a/pgweb/core/views.py b/pgweb/core/views.py
index c1d34d1..44c1b7b 100644
--- a/pgweb/core/views.py
+++ b/pgweb/core/views.py
@@ -140,22 +140,6 @@ def organisationform(request, itemid):
     return simple_form(Organisation, itemid, request, OrganisationForm,
                        redirect='/account/edit/organisations/')
 
-
-# robots.txt
-def robots(request):
-    return HttpResponse("""User-agent: *
-Disallow: /admin/
-Disallow: /account/
-Disallow: /docs/devel/
-Disallow: /list/
-Disallow: /search/
-Disallow: /message-id/raw/
-Disallow: /message-id/flat/
-
-Sitemap: https://www.postgresql.org/sitemap.xml
-""", content_type='text/plain')
-
-
 def _make_sitemap(pagelist):
     resp = HttpResponse(content_type='text/xml')
     x = PgXmlHelper(resp)
diff --git a/pgweb/urls.py b/pgweb/urls.py
index fe1e1c8..22324f9 100644
--- a/pgweb/urls.py
+++ b/pgweb/urls.py
@@ -1,5 +1,5 @@
 from django.conf.urls import include, url
-from django.views.generic import RedirectView
+from django.views.generic import RedirectView, TemplateView
 
 from pgweb.util.signals import register_basic_signal_handlers
 
@@ -94,7 +94,7 @@ urlpatterns = [
     url(r'^about/sponsors/$', pgweb.sponsors.views.sponsors),
     url(r'^about/servers/$', pgweb.sponsors.views.servers),
 
-    url(r'^robots.txt$', pgweb.core.views.robots),
+    url(r'^robots.txt$', TemplateView.as_view(template_name="core/robots.txt", content_type='text/plain')),
 
     ###
     # RSS feeds
diff --git a/templates/core/robots.txt b/templates/core/robots.txt
new file mode 100644
index 0000000..672ab4a
--- /dev/null
+++ b/templates/core/robots.txt
@@ -0,0 +1,10 @@
+User-agent: *
+Disallow: /admin/
+Disallow: /account/
+Disallow: /docs/devel/
+Disallow: /list/
+Disallow: /search/
+Disallow: /message-id/raw/
+Disallow: /message-id/flat/
+
+Sitemap: https://www.postgresql.org/sitemap.xml
-- 
2.11.0

